return {
    -- lsp configuration
    "neovim/nvim-lspconfig",
    event = { "BufReadPre", "BufNewFile" },
    dependencies = {
        "hrsh7th/cmp-nvim-lsp",
        { "antosha417/nvim-lsp-file-operations", config = true },
        "mfussenegger/nvim-jdtls",
    },
    config = function()
        -- import lspconfig plugin
        local lspconfig = require("lspconfig")

        -- import cmp-nvim-lsp plugin
        local cmp_nvim_lsp = require("cmp_nvim_lsp")

        local capabilities = require('lsp-options').capabilities
        local on_attach = require('lsp-options').on_attach

        -- Change the Diagnostic symbols in the sign column (gutter)
        local signs = { Error = "󰅚 ", Warn = "󰀪 ", Hint = "󰌶", Info = "󰋽 " }
        for type, icon in pairs(signs) do
            local hl = "DiagnosticSign" .. type
            vim.fn.sign_define(hl, { text = icon, texthl = hl, numhl = "" })
        end

        lspconfig.bashls.setup({
            capabilities = capabilities,
            on_attach = on_attach,
        })

        lspconfig.clangd.setup({
            cmd = {
                "clangd",
                "--suggest-missing-includes",
                "--clang-tidy",
            },
            filetypes = { "c", "cpp", "objc", "objcpp", "cuda", "proto", "ino" },
            capabilities = capabilities,
            on_attach = on_attach,
        })

        lspconfig.cssls.setup({
            capabilities = capabilities,
            on_attach = on_attach,
        })

        lspconfig.html.setup({
            capabilities = capabilities,
            on_attach = on_attach,
        })

        lspconfig.jsonls.setup({
            capabilities = capabilities,
            on_attach = on_attach,
        })

        -- ┌                                               ┐
        -- │                      LUA                      │
        -- └                                               ┘
        lspconfig.lua_ls.setup({
            capabilities = capabilities,
            on_attach = on_attach,
            settings = {
                Lua = {
                    -- make the language server recognize "vim" global
                    diagnostics = {
                        globals = { "vim" },
                    },
                    workspace = {
                        -- make language server aware of runtime files
                        library = {
                            [vim.fn.expand("$VIMRUNTIME/lua")] = true,
                            [vim.fn.stdpath("config") .. "/lua"] = true,
                        },
                    },
                },
            },
        })

        lspconfig.marksman.setup({
            capabilities = capabilities,
            on_attach = on_attach,
        })

        -- ┌                                               ┐
        -- │                    Python                     │
        -- └                                               ┘
        lspconfig.pyright.setup({
            capabilities = capabilities,
            on_attach = on_attach,
        })

        -- ┌                                               ┐
        -- │            Vue, TS, JS, TSX & JSX             │
        -- └                                               ┘
        lspconfig.volar.setup({
            capabilities = capabilities,
            on_attach = on_attach,
        })
        local mason_packages = vim.fn.stdpath("data") .. "/mason/packages"
        local volar_path = mason_packages .. "/vue-language-server/node_modules/@vue/language-server"
        lspconfig.ts_ls.setup({
            capabilities = capabilities,
            on_attach = on_attach,
            init_options = {
                plugins = {
                    {
                        name = "@vue/typescript-plugin",
                        -- location = "/usr/lib/node_modules/@vue/typescript-plugin",
                        location = volar_path,
                        languages = { "vue" },
                    },
                },
            },
            filetypes = {
                "javascript",
                "typescript",
                "typescriptreact",
                "javascriptreact",
                "vue",
            },
        })

        -- ┌                                               ┐
        -- │                      ASM                      │
        -- └                                               ┘
        lspconfig.asm_lsp.setup({
            on_attach = on_attach,
            capabilities = capabilities,
        })

        -- ┌                                               ┐
        -- │                     LaTeX                     │
        -- └                                               ┘
        lspconfig.texlab.setup({
            cmd = { "texlab" },
            filetypes = { "tex", "latex", "bib" },
            root_dir = function(fname)
                return vim.loop.cwd()
            end,
        })

        -- ┌                                               ┐
        -- │                    Verilog                    │
        -- └                                               ┘
        local lspconfutil = require("lspconfig/util")
        local root_pattern = lspconfutil.root_pattern("veridian.yml", ".git", ".xpr")
        local verilog_root_dir = function()
            local filename = lspconfutil.path.join(vim.loop.cwd(), fname)
            return root_pattern(filename) or lspconfutil.path.dirname(filename)
        end
        lspconfig.veridian.setup({
            capabilities = capabilities,
            on_attach = on_attach,
            root_dir = verilog_root_dir,
        })

        lspconfig.verible.setup({
            -- cmd = { 'verible-verilog-ls', '--rules_config=/home/janis/.config/nvim/util/verible-conf.json' },
            cmd = { "verible-verilog-ls", "--rules=-no-trailing-spaces", "" },
            capabilities = capabilities,
            on_attach = on_attach,
            root_dir = verilog_root_dir,
        })
    end,
}
